@@ -54,6 +54,11 @@ import (
 	"github.com/twpayne/chezmoi/v2/pkg/shell"
 )
 
+// defaultSentinel is a string value used to indicate that the default value
+// should be used. It is a string unlikely to be an actual value set by the
+// user.
+const defaultSentinel = "\x00"
+
 const (
 	logComponentKey                  = "component"
 	logComponentValueEncryption      = "encryption"
@@ -120,6 +125,7 @@ type ConfigFile struct {
 
 	// Password manager configurations.
 	AWSSecretsManager awsSecretsManagerConfig `json:"awsSecretsManager" mapstructure:"awsSecretsManager" yaml:"awsSecretsManager"`
+	AzureKeyVault     azureKeyVaultConfig     `json:"azureKeyVault"     mapstructure:"azureKeyVault"     yaml:"azureKeyVault"`
 	Bitwarden         bitwardenConfig         `json:"bitwarden"         mapstructure:"bitwarden"         yaml:"bitwarden"`
 	Dashlane          dashlaneConfig          `json:"dashlane"          mapstructure:"dashlane"          yaml:"dashlane"`
 	Ejson             ejsonConfig             `json:"ejson"             mapstructure:"ejson"             yaml:"ejson"`
@@ -380,6 +386,7 @@ func newConfig(options ...configOption) (*Config, error) {
 	for key, value := range map[string]any{
 		"awsSecretsManager":        c.awsSecretsManagerTemplateFunc,
 		"awsSecretsManagerRaw":     c.awsSecretsManagerRawTemplateFunc,
+		"azureKeyVault":            c.azureKeyVaultTemplateFunc,
 		"bitwarden":                c.bitwardenTemplateFunc,
 		"bitwardenAttachment":      c.bitwardenAttachmentTemplateFunc,
 		"bitwardenAttachmentByRef": c.bitwardenAttachmentByRefTemplateFunc,
@@ -1127,7 +1134,7 @@ func (c *Config) diffFile(
 	if err := unifiedEncoder.Encode(diffPatch); err != nil {
 		return err
 	}
-	return c.pageOutputString(builder.String(), c.Diff.Pager)
+	return c.pageDiffOutput(builder.String())
 }
 
 // editor returns the path to the user's editor and any extra arguments.
@@ -1551,6 +1558,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newInitCmd(),
 		c.newInternalTestCmd(),
 		c.newLicenseCmd(),
+		c.newMackupCmd(),
 		c.newManagedCmd(),
 		c.newMergeCmd(),
 		c.newMergeAllCmd(),
@@ -1723,10 +1731,16 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 	return nil
 }
 
-// pageOutputString writes output using cmdPager as the pager command.
-func (c *Config) pageOutputString(output, cmdPager string) error {
-	pager := firstNonEmptyString(cmdPager, c.Pager)
-	if c.noPager || pager == "" {
+// pageDiffOutput pages the diff output to stdout.
+func (c *Config) pageDiffOutput(output string) error {
+	pager := c.Diff.Pager
+	switch {
+	case c.noPager:
+		pager = ""
+	case pager == defaultSentinel:
+		pager = c.Pager // Use default pager.
+	}
+	if pager == "" {
 		return c.writeOutputString(output)
 	}
 
@@ -2622,6 +2636,7 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 		},
 		Diff: diffCmdConfig{
 			Exclude:        chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
+			Pager:          defaultSentinel,
 			ScriptContents: true,
 			include:        chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
 		},
